@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use Tie::Array;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 
 sub TIEARRAY
@@ -153,7 +153,7 @@ sub SPLICECAVITY
     $off += $sz if $off < 0;
     my $len = @_ ? shift : $sz - $off;
     no integer;
-    return splice( $self->{ _data }, $off, $len, @_ );
+    return splice( @{$self->{ _data }}, $off, $len, @_ );
 
 }
 
@@ -165,7 +165,7 @@ sub SPLICE
     my $sz = $self->FETCHSIZE;
     $offset += $sz if $offset < 0;
     my $len = @_ ? shift : $sz - $offset;
-    return splice( $self->{ _data }, $offset, $len, @_ );
+    return splice( @{$self->{ _data }}, $offset, $len, @_ );
 }
 
 
